@@ -4,7 +4,7 @@ from distutils.version import \
     StrictVersion  # pylint: disable=no-name-in-module,import-error
 
 from django import get_version
-from django.conf import settings
+# from django.conf import settings
 from django.contrib.auth.models import Group
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ImproperlyConfigured
@@ -14,7 +14,7 @@ from django.utils import timezone
 from jsonfield.fields import JSONField
 from model_utils import Choices
 
-from notifications import settings as notifications_settings
+from notifications import settings as notifications_settings, settings
 from notifications.signals import notify
 from notifications.utils import id2slug
 from swapper import load_model
